<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Kalın</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Yatık</translation>
    </message>
</context>
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../obconf.ui" line="14"/>
        <source>Window Manager Preferences</source>
        <translation>Pencere Yönetici Tercihleri</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="26"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="31"/>
        <source>Appearance</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="36"/>
        <source>Font</source>
        <translation>Yazı tipi</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="41"/>
        <location filename="../obconf.ui" line="102"/>
        <source>Windows</source>
        <translation>Pencereler</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="46"/>
        <source>Move &amp; Resize</source>
        <translation>Taşı ve Boyutlandır</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="51"/>
        <source>Mouse</source>
        <translation>Fare</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="56"/>
        <source>Desktops</source>
        <translation>Masaüstü</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="61"/>
        <source>Margins</source>
        <translation>Kenarlar</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="66"/>
        <source>Dock</source>
        <translation>Rıhtım</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="84"/>
        <source>&amp;Install a new theme...</source>
        <translation>Yeni bir tema &amp;yükle...</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="91"/>
        <source>Create a theme &amp;archive (.obt)...</source>
        <translation>Bir tema &amp;arşivi (.obt) oluştur...</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="108"/>
        <source>&amp;Windows retain a border when undecorated</source>
        <translation>&amp;Pencereler dekor edilmediginde bir kenarda tutulur</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="115"/>
        <source>A&amp;nimate iconify and restore</source>
        <translation>S&amp;imgelendirme ve geri yüklemeyi canlandır</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="125"/>
        <source>Window Titles</source>
        <translation>Pencere Başlıkları</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="131"/>
        <source>Button order:</source>
        <translation>Düğme sırası:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="141"/>
        <source>N: Window icon
L: Window label (Title)
I: Iconify (Minimize)
M: Maximize
C: Close
S: Shade (Roll up)
D: Omnipresent (On all desktops)</source>
        <translation>N: Pencere Simgesi
L: Pencere etiketi (Başlık)
I: Simge durumu (Küçült)
M: Büyüt
C: Kapat
S: Gölge (Hareket)
D: Hazır (Tüm masaüstlerinde)</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="219"/>
        <source>&amp;Active window title: </source>
        <translation>&amp;Etkin pencere başlığı: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="229"/>
        <source>&amp;Inactive window title: </source>
        <translation>&amp;Pasif pencere başlığı: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="239"/>
        <source>Menu &amp;header: </source>
        <translation>Menü &amp;başlığı: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="249"/>
        <source>&amp;Menu Item: </source>
        <translation>&amp;Menü Ögesi: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="259"/>
        <source>Active &amp;On-screen display: </source>
        <translation>&amp;Görünen ekranda etkinleştir: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="269"/>
        <source>Inactive O&amp;n-screen display: </source>
        <translation>G&amp;örünen ekranda pasifleştir: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="283"/>
        <source>Focus &amp;new windows when they appear</source>
        <translation>Göründükleri zaman yeni &amp;pencerelere odaklan</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="290"/>
        <source>&amp;Place new windows under the mouse pointer</source>
        <translation>Yeni pencereleri &amp;fare işaretçisinin altına yerleştir</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="297"/>
        <source>&amp;Center new windows when they are placed</source>
        <translation>&amp;Yeni pencereleri yerleştirildiğinde ortala</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="306"/>
        <source>Prefer to place new windows &amp;on:</source>
        <translation>Yeni pencere yerleştirme &amp;tercihi:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="317"/>
        <source>All monitors</source>
        <translation>Tüm ekranlar</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="322"/>
        <source>The active monitor</source>
        <translation>Etkin ekran</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="327"/>
        <source>The monitor with the mouse</source>
        <translation>Fareyle ekran</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="332"/>
        <source>Primary monitor</source>
        <translation>Birincil ekran</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="342"/>
        <source>Primary Monitor</source>
        <translation>Birincil ekran</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="348"/>
        <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
        <translation>Openbox&apos;ın pencere diyaloglarını yerleştireceği birincil ekran, pencere döndürme için kullanılan gibi.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="358"/>
        <source>Primary &amp;monitor:</source>
        <translation>Birincil &amp;ekran:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="369"/>
        <source>Fixed Monitor</source>
        <translation>Sabit Ekran</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="374"/>
        <source>Active Monitor</source>
        <translation>Etkin Ekran</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="379"/>
        <source>Monitor With Mouse Pointer</source>
        <translation>Ekranı Fareyle İzle</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="387"/>
        <source>&amp;Fixed monitor:</source>
        <translation>&amp;Sabit ekran:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="427"/>
        <source>Moving and Resizing Windows</source>
        <translation>Pencere Taşıma ve Boyutlandırma</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="433"/>
        <source>Update the window contents while &amp;resizing</source>
        <translation>Pence&amp;reyi yeniden boyutlandırırken içeriğini güncelle</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="440"/>
        <source>Drag &amp;threshold distance:</source>
        <translation>&amp;Eşik mesafesini sürükle:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="460"/>
        <source>Amount of resistance against other &amp;windows:</source>
        <translation>Diğer &amp;pencerelere karşı direnç miktarı:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="480"/>
        <source>Amount of resistance against screen &amp;edges:</source>
        <translation>Ekran köş&amp;elerine karşı direnç miktarı:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="500"/>
        <source>&amp;Amount of time to wait before switching:</source>
        <translation>Değiştirme öncesinde bekleme süresi mikt&amp;arı:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="520"/>
        <source>&amp;Switch desktops when moving a window past the screen edge</source>
        <translation>Bir pencere taşınırken ekran kenarından geçerken ma&amp;saüstünü değiştir</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="530"/>
        <source>Information Dialog</source>
        <translation>Bilgi Penceresi</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="537"/>
        <location filename="../obconf.ui" line="566"/>
        <source>Centered</source>
        <translation>Ortalanmış</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="542"/>
        <source>From left edge</source>
        <translation>Sol kenardan</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="547"/>
        <source>From right edge</source>
        <translation>Sağ kenardan</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="555"/>
        <source>Fixed &amp;y position:</source>
        <translation>Sabit &amp;y konumu:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="571"/>
        <source>From top edge</source>
        <translation>Üst kenardan</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="576"/>
        <source>From bottom edge</source>
        <translation>Alt kenardan</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="584"/>
        <source>Information dialog&apos;s &amp;position:</source>
        <translation>Bilgi &amp;penceresinin konumu:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="594"/>
        <source>Fixed &amp;x position:</source>
        <translation>Sabit &amp;x konumu:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="604"/>
        <source>Show &amp;information dialog:</source>
        <translation>B&amp;ilgi penceresini göster:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="629"/>
        <source>When resizing terminal windows</source>
        <translation>Terminal penceresini yeniden boyutlandırırken</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="634"/>
        <source>Always</source>
        <translation>Her Zaman</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="639"/>
        <source>Never</source>
        <translation>Hiçbir Zaman</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="648"/>
        <source>Centered on the window</source>
        <translation>Pencerede ortalanmış</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="653"/>
        <source>Above the window</source>
        <translation>Pencerenin üstünde</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="658"/>
        <source>Fixed position on screen</source>
        <translation>Ekranda sabit konum</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="689"/>
        <source>Focusing Windows</source>
        <translation>Pencerelere Odaklanma</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="698"/>
        <source>Focus windows when the mouse pointer moves over them</source>
        <translation>Fare işaretçisi pencereler üzerinde gezinirken pencerelere odaklan</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="710"/>
        <source>&amp;Delay before focusing and raising windows:</source>
        <translation>Pencerelere odaklanma ve yükselme öncesin&amp;de bekle:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="730"/>
        <source>Move focus under the mouse when &amp;switching desktops</source>
        <translation>Masaüstlerini değiştirirken odağı fare altında hareket ettir</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="737"/>
        <source>Move focus &amp;under the mouse when the mouse is not moving</source>
        <translation>Fare hareket etmezken odağı fare altında hareket ettir</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="744"/>
        <source>&amp;Raise windows when the mouse pointer moves over them</source>
        <translation>Fa&amp;re işaretçisi pencerelerin üzerine geldiğinde pencereleri yükselt</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="756"/>
        <source>Titlebar</source>
        <translation>Başlık Çubuğu</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="762"/>
        <source>Double click on the &amp;titlebar:</source>
        <translation>Başlık çubuğu üzerinde çift &amp;tıkla:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="773"/>
        <source>Maximizes the window</source>
        <translation>Pencereyi büyüt</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="778"/>
        <source>Shades the window</source>
        <translation>Pencereyi gölgeler</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="786"/>
        <source>Double click ti&amp;me:</source>
        <translation>Za&amp;manı çift tıkla:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="826"/>
        <source>&amp;Show a notification when switching desktops</source>
        <translation>Masaüstü değiştirilirken bir uyarı gö&amp;ster</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="833"/>
        <source>&amp;Amount of time to show the notification for:</source>
        <translation>Gösterilecek uy&amp;arı için bekleme süresi:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="856"/>
        <source>&amp;Number of desktops: </source>
        <translation>Masaüstü &amp;sayısı: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="879"/>
        <source>&amp;Desktop names:</source>
        <translation>Masaüstü a&amp;dı:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="893"/>
        <source>Desktop Margins</source>
        <translation>Masaüstü Kenarları</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="899"/>
        <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
        <translation>Masaüstü kenar boşlukları, ekranınızın kenarında ayrılmış alanlardır.  Yeni pencereler bir kenar boşluğuna yerleştirilmeyecek ve büyütülmüş pencereler bunları kaplamayacak.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="909"/>
        <source>Left:</source>
        <translation>Sol:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="923"/>
        <location filename="../obconf.ui" line="944"/>
        <location filename="../obconf.ui" line="965"/>
        <location filename="../obconf.ui" line="986"/>
        <source>px</source>
        <translation>nk</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="930"/>
        <source>Top:</source>
        <translation>Üst:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="951"/>
        <source>Right:</source>
        <translation>Sağ:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="972"/>
        <source>Bottom:</source>
        <translation>Alt:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1013"/>
        <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
        <translation>Rıhtım, &quot;dockapps&quot; veya rıhtım uygulamaları için özel bir konteynırdır. Bir rıhtım uygulaması çalıştırılana kadar ekranda görünmez.  Rıhtım Uygulaması, bir saat gibi şeyler göstermek veya bir sistem tepsisi sağlamak için kullanılabilir.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1029"/>
        <source>Position</source>
        <translation>Konum</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1041"/>
        <source>&amp;Position:</source>
        <translation>&amp;Konum:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1055"/>
        <source>Top Left</source>
        <translation>Sol Üst</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1060"/>
        <source>Top</source>
        <translation>Üst</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1065"/>
        <source>Top Right</source>
        <translation>Sağ Üst</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1070"/>
        <source>Left</source>
        <translation>Sol</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1075"/>
        <source>Right</source>
        <translation>Sağ</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1080"/>
        <source>Bottom Left</source>
        <translation>Sol Alt</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1085"/>
        <source>Bottom</source>
        <translation>Alt</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1090"/>
        <source>Bottom Right</source>
        <translation>Sağ Alt</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1095"/>
        <source>Floating</source>
        <translation>Yüzen</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1109"/>
        <source>&amp;Floating position:</source>
        <translation>&amp;Yüzme konumu:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1134"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1150"/>
        <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
        <translation>&amp;Pencerelerin rıhtım alanına yerleştirilmesine izin ver</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1157"/>
        <source>&amp;Orientation: </source>
        <translation>&amp;Yönlendirme: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1171"/>
        <source>Vertical</source>
        <translation>Dikey</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1176"/>
        <source>Horizontal</source>
        <translation>Yatay</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1187"/>
        <source>Stacking</source>
        <translation>Yerleşim</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1193"/>
        <source>Keep dock &amp;above other windows</source>
        <translation>Rıhtımı diğer pencerelerin &amp;üzerinde tut</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1200"/>
        <source>A&amp;llow dock to be both above and below windows</source>
        <translation>Rıhtımın pencerelerin hem altında hem üzerinde o&amp;lmasına izin ver</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1207"/>
        <source>Keep dock &amp;below other windows</source>
        <translation>Rıhtımı diğer pencerelerin &amp;altında tut</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1217"/>
        <source>Hiding</source>
        <translation>Gizleme</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1223"/>
        <source>&amp;Delay before hiding:</source>
        <translation>Gizleme öncesi &amp;bekle:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1233"/>
        <source>Delay before &amp;showing:</source>
        <translation>Gö&amp;sterme öncesi bekle:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1263"/>
        <source>&amp;Hide off screen</source>
        <translation>Ekranı &amp;gizle</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1294"/>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
</context>
<context>
    <name>Obconf::MainDialog</name>
    <message>
        <location filename="../theme.cpp" line="152"/>
        <source>Choose an Openbox theme</source>
        <translation>Bir Openbox teması seç</translation>
    </message>
    <message>
        <location filename="../desktops.cpp" line="67"/>
        <location filename="../desktops.cpp" line="89"/>
        <location filename="../desktops.cpp" line="101"/>
        <source>(Unnamed desktop)</source>
        <translation>(İsimsiz masaüstü)</translation>
    </message>
    <message>
        <location filename="../mouse.cpp" line="56"/>
        <source>Custom actions</source>
        <translation>Özel eylemler</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="78"/>
        <source>About ObConf-Qt</source>
        <translation>ObConf-Qt Hakkında</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="79"/>
        <source>A preferences manager for Openbox

Copyright (c) 2014-2015

Authors:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

The program is based on ObConf developed by the following developers.
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
        <translation>Openbox için bir tercih yöneticisi

Telif Hakkı (c) 2014-2015

Yazarlar:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

ObConf temelli program aşağıdaki geliştiriciler tarafından geliştirilmektedir.
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../archive.cpp" line="26"/>
        <source>&quot;%1&quot; was installed to %2</source>
        <translation>&quot;%1&quot; %2 ögesine yüklendi</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="53"/>
        <source>&quot;%1&quot; was successfully created</source>
        <translation>&quot;%1&quot; başarılı bir şekilde oluşturuldu</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="89"/>
        <source>Unable to create the theme archive &quot;%1&quot;.
The following errors were reported:
%2</source>
        <translation>&quot;%1&quot; tema arşivi oluşturma başarısız.
Aşağıdaki hatalar bildirildi:
%2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="95"/>
        <location filename="../archive.cpp" line="180"/>
        <source>Unable to run the &quot;tar&quot; command: %1</source>
        <translation>&quot;tar&quot; komutu çalıştıralamıyor: %1</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="115"/>
        <source>Unable to create directory &quot;%1&quot;: %2</source>
        <translation>&quot;%1&quot; dizini oluşturulamıyor: %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="138"/>
        <source>&quot;%1&quot; does not appear to be a valid Openbox theme directory</source>
        <translation>&quot;%1&quot; geçerli bir Openbox tema dizini gibi görünmüyor</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="187"/>
        <source>Unable to extract the file &quot;%1&quot;.
Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
The following errors were reported:
%3</source>
        <translation>&quot;%1&quot; dosyası çıkartılamıyor.
Lütfen &quot;%2&quot; dizininin yazılabilir ve geçerli bir Openbox tema arşivi olduğundan emin olunuz.
Aşağıdaki hatalar bildirildi:
%3</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="53"/>
        <source>ObConf Error</source>
        <translation>Obconf Hatası</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="58"/>
        <source>Copyright (c) 2003-2008   Dana Jansens
Copyright (c) 2003        Tim Riley
Copyright (c) 2007        Javeed Shaikh
Copyright (c) 2013        Hong Jen Yee (PCMan)

This program comes with ABSOLUTELY NO WARRANTY.
This is free software, and you are welcome to redistribute it
under certain conditions. See the file COPYING for details.

</source>
        <translation>Telif Hakkı (c) 2003-2008   Dana Jansens
Telif Hakkı (c) 2003        Tim Riley
Telif Hakkı (c) 2007        Javeed Shaikh
Telif Hakkı (c) 2013        Hong Jen Yee (PCMan)

Bu program KESİNLİKLE HİÇBİR GARANTİ ile gelmez.
Bu ücretsiz bir yazılımdır ve bunu belirli koşullar altında 
yeniden dağıtabilirsiniz. Ayrıntılar için COPYING dosyasına 
bakınız.

</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="73"/>
        <source>Syntax: obconf [options] [ARCHIVE.obt]

Options:
  --help                Display this help and exit
  --version             Display the version and exit
  --install ARCHIVE.obt Install the given theme archive and select it
  --archive THEME       Create a theme archive from the given theme directory
  --config-file FILE    Specify the path to the config file to use
</source>
        <translation>Sözdizimi: obconf [seçenekler] [ARCHIVE.obt]

Seçenekler:
   -- help                   Bu yardımı görüntüle ve çık
   -- version              Sürümü görüntüler ve çık
   -- install ARCHIVE.obt    Verilen tema arşivini yükle ve onu seç
   --archive THEME       Verilen tema dizininden bir tema arşivi oluşturun
   --config-file FILE        Kullanılacak yapılandırma dosyasının yolunu belirtin
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="97"/>
        <source>--install requires an argument
</source>
        <translation>--install bir argüman gerektirir
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="103"/>
        <source>--archive requires an argument
</source>
        <translation>--archive bir argüman gerektirir
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="109"/>
        <source>--config-file requires an argument
</source>
        <translation>--config-file bir argüman gerektirir
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="206"/>
        <source>Platform Unsupported</source>
        <translation>Desteklenmeyen Platform</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="207"/>
        <source>ObConf-Qt is unsupported under Wayland.
</source>
        <translation>ObConf-Qt Wayland altında desteklenmemektedir.
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="241"/>
        <location filename="../obconf-qt.cpp" line="256"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="242"/>
        <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
        <translation>Bir rc.xml yüklenemedi. Muhtemelen Openbox&apos;ı uygun bir şekilde yükleyemediniz.</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="254"/>
        <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.

Message: %1</source>
        <translation>Openbox yapılandırma dosyası ayrıştırılırken hata oluştu. Yapılandırma dosyanız geçerli XML dosyası değil.

İleti: %1</translation>
    </message>
</context>
</TS>
